﻿import util.Observable;

/**
 * This Observer pattern based class acts as an object in 3D space.
 * The x,y,z properties are linked to an automatic update, so that
 * whenever the camera changes (moves or rotates), the 3DScene will update
 * the canvas with all 3D objects.
 */
class graphical.CameraView extends Observable {
	// internal 3D location
	private var _x, _y, _z:Number;
	
	/**
	 * Constructor: Initializes the camera with a 3D location
	 */
	public function CameraView(x:Number, y:Number, z:Number) {
		this._x = x;
		this._y = y;
		this._z = z;
	}
	
	// bunch of gets
	public function get x() { return _x; }
	public function get y() { return _y; }
	public function get z() { return _z; }
	
	// bunch of sets, which trigger an update
	public function set x(newX:Number){ if (_x != newX) {_x = newX; update();} }
	public function set y(newY:Number){ if (_y != newY) {_y = newY; update();} }
	public function set z(newZ:Number){ if (_z != newZ) {_z = newZ; update();} }
	
	/**
	 * Updates whatever observer is watching this camera.
	 * It is possible to have multiple 3DScenes watching this camera.
	 */
	public function update() {
		setChanged();
      	notifyObservers();
	}
}
